package ttweetnacl

  1. Overview
  2. Docs

Module CRYPTO.ScalarmultSource

Scalar multiplication.

The primitive is curve25519, NaCl documentation.

Sourcetype scalar = Bytes.t

The type for scalars.

Sourceval scalar_length : int

scalar_length is the byte length of scalars.

Sourcetype group_element = Bytes.t

The type for group elements.

Sourceval group_element_length : int

group_element_length is the byte length of group elements.

mult n p multiplies p by n. Raises Invalid_argument if either n or p has not the right length.

base n multiplies a standard group element by n. Raises Invalid_argument if n has not the right length.